NetworkChainTipHeightEstimator

Struct NetworkChainTipHeightEstimator 

pub struct NetworkChainTipHeightEstimator {
    current_block_time: DateTime<Utc>,
    current_height: Height,
    current_target_spacing: Duration,
    next_target_spacings: IntoIter<(Height, Duration)>,
}
A type used to estimate the chain tip height at a given time.

The estimation is based on a known block time and height for a block. The estimator will then handle any target spacing changes to extrapolate the provided information into a target time and obtain an estimation for the height at that time.

Usage

  1. Use NetworkChainTipHeightEstimator::new to create and initialize a new instance with the information about a known block.
  2. Use NetworkChainTipHeightEstimator::estimate_height_at to obtain a height estimation for a given instant.

Fields

current_block_time: DateTime<Utc>current_height: Heightcurrent_target_spacing: Durationnext_target_spacings: IntoIter<(Height, Duration)>

Implementations

Source

impl NetworkChainTipHeightEstimator

pub fn new( current_block_time: DateTime<Utc>, current_height: Height, network: &Network, ) -> Self

Create a NetworkChainTipHeightEstimator and initialize it with the information to use for calculating a chain height estimate.

The provided information (current_block_time, current_height and network) must refer to the same block.

Implementation details

The network is used to obtain a list of target spacings used in different sections of the block chain. The first section is used as a starting point.

pub fn estimate_height_at(self, target_time: DateTime<Utc>) -> Height

Estimate the network chain tip height at the provided target_time.

Implementation details

The current_block_time and the current_height is advanced to the end of each section that has a different target spacing time. Once the current_block_time passes the target_time, the last active target spacing time is used to calculate the final height estimation.

fn estimate_up_to(&mut self, max_height: Height)

Advance the current_block_time and current_height to the next change in target spacing time.

The current_height is advanced to max_height (if it’s not already past that height). The amount of blocks advanced is then used to extrapolate the amount to advance the current_block_time.

fn estimate_height_at_with_current_target_spacing( self, target_time: DateTime<Utc>, ) -> Height

Calculate an estimate for the chain height using the current_target_spacing.

Using the difference between the target_time and the current_block_time and the current_target_spacing, the number of blocks to reach the target_time from the current_block_time is calculated. The value is added to the current_height to calculate the final estimate.